aboutsummaryrefslogtreecommitdiffstats
path: root/python
diff options
context:
space:
mode:
Diffstat (limited to 'python')
-rw-r--r--python/fatcat/crossref_importer.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/python/fatcat/crossref_importer.py b/python/fatcat/crossref_importer.py
index 2154c8c0..38a4bc11 100644
--- a/python/fatcat/crossref_importer.py
+++ b/python/fatcat/crossref_importer.py
@@ -89,10 +89,10 @@ class FatcatCrossrefImporter(FatcatImporter):
for i, rm in enumerate(obj.get('reference', [])):
try:
year = int(rm.get('year'))
- if year > 2025 or year < 1000:
- # NOTE: will need to update/config in the future!
- # NOTE: are there crossref works with year < 1000?
- return None
+ # NOTE: will need to update/config in the future!
+ # NOTE: are there crossref works with year < 100?
+ if year > 2025 or year < 100:
+ year = None
except:
year = None
extra = dict(crossref=rm)